@@ -1,3 +1,4 @@
+import re
 from robotframework_ls.impl.protocols import (
     ICompletionContext,
     IDefinition,
@@ -7,6 +8,7 @@ from robotframework_ls.impl.protocols import (
 from robocorp_ls_core.protocols import check_implements
 from typing import Optional, Sequence
 
+_RF_VARIABLE = re.compile(r"([$|&|@]{[\w\s]+})")
 
 class _DefinitionFromKeyword(object):
     def __init__(self, keyword_found):
@@ -266,9 +268,9 @@ def find_definition(completion_context: ICompletionContext) -> Sequence[IDefinit
 
         token = token_info.token
         value = token.value
-
+        match = next(iter(_RF_VARIABLE.findall(value)), value)
         collector = _FindDefinitionVariablesCollector(
-            completion_context.sel, token, RobotStringMatcher(value)
+            completion_context.sel, token, RobotStringMatcher(match)
         )
         collect_variables(completion_context, collector)
         return collector.matches
