@@ -5,17 +5,26 @@ from robotframework_ls.constants import NULL
 from robocorp_ls_core.robotframework_log import get_logger
 from robotframework_ls.impl.protocols import IRobotWorkspace, IRobotDocument
 from robocorp_ls_core.protocols import check_implements, IWorkspaceFolder
+from robocorp_ls_core.watchdog_wrapper import IFSObserver
+from typing import Optional, Any
 
 log = get_logger(__name__)
 
 
 class RobotWorkspace(Workspace):
     def __init__(
-        self, root_uri, workspace_folders=None, libspec_manager=NULL, generate_ast=True
+        self,
+        root_uri,
+        fs_observer: IFSObserver,
+        workspace_folders=None,
+        libspec_manager=NULL,
+        generate_ast=True,
     ):
         self.libspec_manager = libspec_manager
 
-        Workspace.__init__(self, root_uri, workspace_folders=workspace_folders)
+        Workspace.__init__(
+            self, root_uri, fs_observer, workspace_folders=workspace_folders
+        )
         self._generate_ast = generate_ast
 
     @overrides(Workspace.add_folder)
@@ -53,6 +62,8 @@ class RobotDocument(Document):
         Document._clear_caches(self)
         self._symbols_cache = None
         self.get_ast.cache_clear(self)  # noqa (clear the instance_cache).
+        self.get_python_ast.cache_clear(self)  # noqa (clear the instance_cache).
+        self.get_yaml_contents.cache_clear(self)  # noqa (clear the instance_cache).
 
     def get_type(self):
         path = self.path
@@ -110,6 +121,47 @@ class RobotDocument(Document):
             ast.source = self.path
             return ast
 
+    @instance_cache
+    def get_python_ast(self):
+        if not self._generate_ast:
+            raise AssertionError(
+                "The AST can only be accessed in the RobotFrameworkServerApi, not in the RobotFrameworkLanguageServer."
+            )
+
+        try:
+            source = self.source
+        except:
+            log.exception("Error getting source for: %s" % (self.uri,))
+            return None
+
+        try:
+            import ast as ast_module
+
+            return ast_module.parse(source)
+        except:
+            log.critical(f"Error parsing python file: {self.uri}")
+            return None
+
+    @instance_cache
+    def get_yaml_contents(self) -> Optional[Any]:
+        try:
+            source = self.source
+        except:
+            log.exception("Error getting source for: %s" % (self.uri,))
+            return None
+
+        try:
+            from robocorp_ls_core import yaml_wrapper
+            from io import StringIO
+
+            s = StringIO()
+            s.write(source)
+            s.seek(0)
+            return yaml_wrapper.load(s)
+        except:
+            log.critical(f"Error parsing yaml file: {self.uri}")
+            return None
+
     def find_line_with_contents(self, contents: str) -> int:
         """
         :param contents:
