@@ -11,7 +11,6 @@ from robocorp_ls_core.protocols import (
     IIdMessageMatcher,
     IRobotFrameworkApiClient,
     IMonitor,
-    ActionResultDict,
 )
 from pathlib import Path
 from robotframework_ls.ep_providers import (
@@ -23,10 +22,11 @@ from robocorp_ls_core.jsonrpc.endpoint import require_monitor
 from robocorp_ls_core.jsonrpc.monitor import Monitor
 from functools import partial
 import itertools
-from robotframework_ls import __version__
+from robotframework_ls import __version__, rf_interactive_integration
 import typing
 import sys
 from robocorp_ls_core.watchdog_wrapper import IFSObserver
+from robocorp_ls_core.lsp import CodeLensTypedDict
 
 
 log = get_logger(__name__)
@@ -128,6 +128,7 @@ class _LintManager(object):
 class RobotFrameworkLanguageServer(PythonLanguageServer):
     def __init__(self, rx, tx) -> None:
         from robocorp_ls_core.pluginmanager import PluginManager
+        from robotframework_ls.rf_interactive_integration import _RfInterpretersManager
         from robotframework_ls.server_manager import ServerManager
         from robotframework_ls.ep_providers import DefaultConfigurationProvider
         from robotframework_ls.ep_providers import DefaultEndPointProvider
@@ -158,6 +159,7 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
         self._pm.set_instance(
             EPEndPointProvider, DefaultEndPointProvider(self._endpoint)
         )
+        self._rf_interpreters_manager = _RfInterpretersManager(self._endpoint, self._pm)
 
         watch_impl = os.environ.get("ROBOTFRAMEWORK_LS_WATCH_IMPL", "auto")
         if watch_impl not in ("watchdog", "fsnotify", "auto"):
@@ -273,9 +275,7 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
 
         server_capabilities = {
             "codeActionProvider": False,
-            "codeLensProvider": {
-                "resolveProvider": False  # We may need to make this configurable
-            },
+            "codeLensProvider": {"resolveProvider": True},
             "completionProvider": {
                 "resolveProvider": False  # We know everything ahead of time
             },
@@ -370,6 +370,11 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
         elif command == "robot.getLanguageServerVersion":
             return __version__
 
+        elif command.startswith("robot.internal.rfinteractive."):
+            return rf_interactive_integration.execute_command(
+                command, self, self._rf_interpreters_manager, arguments
+            )
+
         elif command == "robot.listTests":
             doc_uri = arguments[0]["uri"]
 
@@ -628,7 +633,7 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
         self,
         rf_api_client: IRobotFrameworkApiClient,
         request_method_name: str,
-        monitor: IMonitor,
+        monitor: Optional[IMonitor],
         **kwargs,
     ):
         from robocorp_ls_core.client_base import wait_for_message_matcher
@@ -751,6 +756,30 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
         log.info("Unable to get code lens (no api available).")
         return []
 
+    def m_code_lens__resolve(self, **kwargs):
+        code_lens: CodeLensTypedDict = kwargs
+
+        code_lens_command = code_lens.get("command")
+        data = code_lens.get("data")
+        if code_lens_command is None and isinstance(data, dict):
+            # For the interactive shell we need to resolve the arguments.
+            uri = data.get("uri")
+
+            rf_api_client = self._server_manager.get_others_api_client(uri)
+            if rf_api_client is not None:
+                func = partial(
+                    self._async_api_request_no_doc,
+                    rf_api_client,
+                    "request_resolve_code_lens",
+                    code_lens=code_lens,
+                )
+                func = require_monitor(func)
+                return func
+
+            log.info("Unable to resolve code lens (no api available).")
+
+        return code_lens
+
     def m_text_document__document_symbol(self, **kwargs):
         doc_uri = kwargs["textDocument"]["uri"]
 
