@@ -27,6 +27,7 @@ from robocorp_ls_core.protocols import IEndPoint, IFuture, TypedDict
 
 
 class CompletionItemKind(object):
+    User = 0
     Text = 1
     Method = 2
     Function = 3
@@ -45,6 +46,14 @@ class CompletionItemKind(object):
     Color = 16
     File = 17
     Reference = 18
+    Folder = 19
+    EnumMember = 20
+    Constant = 21
+    Struct = 22
+    Event = 23
+    Operator = 24
+    TypeParameter = 25
+    Issue = 26
 
 
 class MarkupKind(object):
@@ -183,7 +192,7 @@ class CompletionItem(_Base):
         sortText=None,  # str
         filterText=None,  # str
         insertText=None,  # str
-        insertTextFormat=None,  # str
+        insertTextFormat=None,  # int
         text_edit=None,  # TextEdit
         additionalTextEdits=None,  # List['TextEdit']
         commitCharacters=None,  # List[str]
@@ -407,9 +416,9 @@ class SymbolInformationTypedDict(TypedDict, total=False):
 
 class TextDocumentTypedDict(TypedDict, total=False):
     uri: str
-    languageId: str  # Optional
-    version: int  # Optional
-    text: str  # Optional
+    languageId: Optional[str]
+    version: Optional[int]
+    text: Optional[str]
 
 
 class MarkupContentTypedDict(TypedDict):
@@ -417,6 +426,117 @@ class MarkupContentTypedDict(TypedDict):
     value: str
 
 
+class CompletionItemTypedDict(TypedDict, total=False):
+    #
+    # The label of this completion item. By default
+    # also the text that is inserted when selecting
+    # this completion.
+    label: str
+    #
+    # The kind of this completion item. Based of the kind
+    # an icon is chosen by the editor.
+    kind: int  # CompletionItemKind
+    #
+    # Tags for this completion item.
+    #
+    # @since 3.15.0
+    tags: Optional[Any]  # List[CompletionItemTag]
+    #
+    # A human-readable string with additional information
+    # about this item, like type or symbol information.
+    detail: Optional[str]
+    #
+    # A human-readable string that represents a doc-comment.
+    documentation: Optional[Union[str, MarkupContentTypedDict]]
+    #
+    # Indicates if this item is deprecated.
+    # @deprecated Use `tags` instead.
+    deprecated: Optional[bool]
+    #
+    # Select this item when showing.
+    #
+    # *Note* that only one completion item can be selected and that the
+    # tool / client decides which item that is. The rule is that the *first*
+    # item of those that match best is selected.
+    preselect: Optional[bool]
+    #
+    # A string that should be used when comparing this item
+    # with other items. When `falsy` the [label](#CompletionItem.label)
+    # is used.
+    sortText: Optional[str]
+    #
+    # A string that should be used when filtering a set of
+    # completion items. When `falsy` the [label](#CompletionItem.label)
+    # is used.
+    filterText: Optional[str]
+    #
+    # A string that should be inserted into a document when selecting
+    # this completion. When `falsy` the [label](#CompletionItem.label)
+    # is used.
+    #
+    # The `insertText` is subject to interpretation by the client side.
+    # Some tools might not take the string literally. For example
+    # VS Code when code complete is requested in this example `con<cursor position>`
+    # and a completion item with an `insertText` of `console` is provided it
+    # will only insert `sole`. Therefore it is recommended to use `textEdit` instead
+    # since it avoids additional client side interpretation.
+    insertText: Optional[str]
+    #
+    # The format of the insert text. The format applies to both the `insertText` property
+    # and the `newText` property of a provided `textEdit`. If omitted defaults to
+    # `InsertTextFormat.PlainText`.
+    insertTextFormat: Optional[int]  # InsertTextFormat
+    #
+    # How whitespace and indentation is handled during completion
+    # item insertion. If ignored the clients default value depends on
+    # the `textDocument.completion.insertTextMode` client capability.
+    #
+    # @since 3.16.0
+    insertTextMode: Optional[Any]  # InsertTextMode
+    #
+    # An [edit](#TextEdit) which is applied to a document when selecting
+    # this completion. When an edit is provided the value of
+    # [insertText](#CompletionItem.insertText) is ignored.
+    #
+    # Most editors support two different operation when accepting a completion item. One is to insert a
+    # completion text and the other is to replace an existing text with a completion text. Since this can
+    # usually not predetermined by a server it can report both ranges. Clients need to signal support for
+    # `InsertReplaceEdits` via the `textDocument.completion.insertReplaceSupport` client capability
+    # property.
+    #
+    # *Note 1:* The text edit's range as well as both ranges from a insert replace edit must be a
+    # [single line] and they must contain the position at which completion has been requested.
+    # *Note 2:* If an `InsertReplaceEdit` is returned the edit's insert range must be a prefix of
+    # the edit's replace range, that means it must be contained and starting at the same position.
+    #
+    # @since 3.16.0 additional type `InsertReplaceEdit`
+    textEdit: Optional[Any]  # Union[TextEdit, InsertReplaceEdit]
+    #
+    # An optional array of additional [text edits](#TextEdit) that are applied when
+    # selecting this completion. Edits must not overlap (including the same insert position)
+    # with the main [edit](#CompletionItem.textEdit) nor with themselves.
+    #
+    # Additional text edits should be used to change text unrelated to the current cursor position
+    # (for example adding an import statement at the top of the file if the completion item will
+    # insert an unqualified type).
+    additionalTextEdits: Optional[List[TextEdit]]
+    #
+    # An optional set of characters that when pressed while this completion is active will accept it first and
+    # then type that character. *Note* that all commit characters should have `length=1` and that superfluous
+    # characters will be ignored.
+    commitCharacters: Optional[List[str]]
+    #
+    # An optional [command](#Command) that is executed *after* inserting this completion. *Note* that
+    # additional modifications to the current document should be described with the
+    # [additionalTextEdits](#CompletionItem.additionalTextEdits)-property.
+    command: Optional[Any]  # Command
+    #
+    # A data entry field that is preserved on a completion item between
+    # a [CompletionRequest](#CompletionRequest) and a [CompletionResolveRequest]
+    # (#CompletionResolveRequest)
+    data: Optional[Any]
+
+
 class HoverTypedDict(TypedDict, total=False):
     contents: MarkupContentTypedDict
     range: RangeTypedDict  # Optional
@@ -552,6 +672,10 @@ class LSPMessages(object):
     def __init__(self, endpoint: IEndPoint):
         self._endpoint = endpoint
 
+    @property
+    def endpoint(self) -> IEndPoint:
+        return self._endpoint
+
     def apply_edit(self, edit):
         return self._endpoint.request(self.M_APPLY_EDIT, {"edit": edit})
 
